@@ -13,9 +13,10 @@ tex_build <- function(tex_lines,
   
   interaction_mode <- ifelse(tex_message, "nonstopmode", "batchmode")
   
-  temp_tex    <- file.path(fileDir,sprintf("%sDoc.tex",stem))
-  temp_stdout <- file.path(fileDir,sprintf('%s_stdout.txt',stem))
-  temp_stderr <- file.path(fileDir,sprintf('%s_stderr.txt',stem))
+  temp_tex    <- sprintf("%sDoc.tex",stem)
+  temp_log    <- sprintf('%sDoc.log',stem)
+  temp_out <- sprintf('%s_stdout.txt',stem)
+  temp_err <- sprintf('%s_stderr.txt',stem)
   
   tex_args <- c('-synctex=1',
                 sprintf('-interaction=%s',interaction_mode),
@@ -24,12 +25,12 @@ tex_build <- function(tex_lines,
   
   writeLines(tex_lines, con = temp_tex)
 
-  system2(engine, args = tex_args, stdout = temp_stdout, stderr = temp_stderr,...)
+  system2(engine, args = tex_args, stdout = temp_out, stderr = temp_err,...)
   
-  log_lines <- readLines(tex_path(fileDir,stem = paste0(stem,'Doc'),dev = 'log'))
+  log_lines <- readLines(temp_log)
   
   attr(log_lines,'error') <- grepl('error',log_lines[length(log_lines)])
 
   log_lines
   
-}
\ No newline at end of file
+}
